. tests/common.sh

#------------------------------------------------------

test_initialize
test_set_hook result test_result_hook_save_output_on_failure

#------------------------------------------------------
# test whether the given input scattering table is reproduced on output
# this is for the new scattering table format.

NRAYS=100000

# in-plane only

exec 3< $inputs_dir/sawtooth.input

while read -u 3 esa theta energy exp ; do

  test_begin_subtests

    $TEST_SCATTER		\
       --seed1 $SEED1		\
       --seed2 $SEED2		\
       --block $BLOCK		\
       --nrays $NRAYS		\
       --alpha $theta		\
       --in_plane		\
       --no-out_of_plane	\
       --flip			\
       --energy $energy		\
       --tag=$(testpfx)		\
       --srcdir=$scatter_dir	\
       --zpos=0			\
       --mirror_db='${INPUTDIR}/mirror.rdb' \
       --scatter_db='${INPUTDIR}/sawtooth.rdb'

    test_ok $? "new: esa = $esa: generate test output"

    test_set check_exit_status 1
    P=$(./test_smirnov $inputs_dir/$exp theta $(testpfx).scatter.calc.fits theta)
    test_ndiff_is -a "-relerr .001" "$P" 1.0 "new: esa = $esa; theta"

    for delta in min max ; do
        dT=$(perl -lane 'print abs($F[1]) if $F[0] eq "'${delta}':"' $(testpfx).dtheta)
	test_ndiff_is -a "-abserr 1e-16" "$dT" 0 "new: esa = $esa; dtheta ${delta}"
    done


    test_set check_exit_status 0

  test_end_subtests

done

test_summary
test_exit
